@@ -77,52 +77,21 @@ class WaifuAioClient:
         else:
             raise APIException(response.status,response.reason,infos['error'])
 
+    def _create_params(self,**kwargs):
+        rt={k:','.join(i) if isinstance(i,list) else str(i) for k,i in kwargs.items() if i}
+        if rt:
+            return rt
+
     async def _fetchtag(self, type_, tag, raw, exclude, gif, many):
         """process the request for a specific tag and check if everything is correct."""
-        params={}
-        headers={}
-        if many is not None:
-            params.update({'many':str(many)})
-        if gif is not None:
-            params.update({'gif':str(gif)})
-        if exclude is not None:
-            params.update({'exclude':','.join(exclude)})
-        if self.appname:
-            headers.update({'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}'})
-        infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/",'get',params=params,headers=None if not headers else headers)
+        params=self._create_params(exclude=exclude,gif=gif,many=many)
+        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
+        infos= await self._make_request(f"{APIBaseURL}{type_}/{tag}/",'get',params=params,headers=headers)
         if raw:
             return infos
         return [im.get('url') for im in infos.get('tags')[0].get('images')] if many else infos.get('tags')[0].get('images')[0].get('url')
 
 
-    async def _fetchgallery(self, user_id, toggle, insert, delete, token):
-        """process the request for a specific tag and check if everything is correct."""
-        params={}
-        headers={}
-        if user_id:
-            params.update({'id':user_id})
-        if toggle:
-            params.update({'toggle':','.join(toggle)})
-        if delete:
-            params.update({'delete':','.join(delete)})
-        if insert:
-            params.update({'insert':','.join(insert)})
-        if self.appname:
-            headers={'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}'}
-        if not token:
-            token=self.token
-        headers.update({'Authorization':f'Bearer {token}'})
-        return await self._make_request(f"{APIBaseURL}fav/",'get',params=params,headers=None if not headers else headers)
-
-    async def _fetchendpoints(self, full=False):
-        endpointurl=f"{APIBaseURL}/endpoints/"
-        headers={}
-        if full:
-            endpointurl=f"{APIBaseURL}/endpoints_info/"
-        if self.appname:
-            headers.update({'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}'})
-        return await self._make_request(endpointurl,'get',headers=None if not headers else headers)
-
     async def sfw(self, tag: Union[int,str], raw: bool=False, exclude: List[str]=None, gif: bool=None, many: bool=None):
         """Gets a single or multiple unique SFW images of the specific category.
         Args:
@@ -156,15 +125,14 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        data = await self._fetchtag('nsfw',tag,raw,exclude,gif,many)
-        return data
+        return await self._fetchtag('nsfw',tag,raw,exclude,gif,many)
 
     @requires_token
     async def fav(self, user_id: str=None,toggle : List[str]=None,insert: List[str]=None, delete: List[str]=None, token: str=None):
         """Get your favorite gallery.""
 
         Kwargs:
-            id: The user's id you want to access the gallery (only for trusted apps).
+            user_id: The user's id you want to access the gallery (only for trusted apps).
             toggle: A list of file names that you want to add if they do not already exist in, else remove, to your gallery in the same time.
             insert: A list of file names that you want to add to your gallery in the same time.
             delete: A list of file names that you want to remove from your gallery in the same time.
@@ -174,7 +142,21 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        return await self._fetchgallery(user_id,toggle,insert,delete,token)
+        params=self._create_params(id=user_id,toggle=toggle,insert=insert,delete=delete)
+        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None,'Authorization':f'Bearer {token if token else self.token}'})
+        return await self._make_request(f"{APIBaseURL}fav/",'get',params=params,headers=headers)
+
+    async def info(self,images :List[str]=None):
+        """Fetch the images data (as if you where requesting a gallery containing only those images
+        Kwargs:
+            images : A list of images filenames to provide.
+        Raises:
+            APIException: If the API response contains an error.
+        """
+        params=self._create_params(images=images)
+        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
+        return await self._make_request(f"{APIBaseURL}info/",'get',params=params,headers=headers)
+
 
     async def endpoints(self, full=False):
         """Gets the API endpoints.
@@ -187,8 +169,11 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        data = await self._fetchendpoints(full=full)
-        return data
+        endpointurl=APIBaseURL+"endpoints_info/" if full else "/endpoints/"
+        headers=self._create_params(**{'User-Agent':f'aiohttp/{aiohttp.__version__}; {self.appname}' if self.appname else None})
+        if full:
+            endpointurl=f"{APIBaseURL}/endpoints_info/"
+        return await self._make_request(endpointurl,'get',headers=headers)
 
 
 
